# Generated by roxygen2: do not edit by hand

S3method(decompose_uncertainty,default)
S3method(decompose_uncertainty,et_prediction)
S3method(decompose_uncertainty,et_prediction_list)
S3method(et_calibrate,et_prediction)
S3method(et_calibrate,et_prediction_list)
S3method(et_diagnose,et_model)
S3method(et_diagnose,et_model_list)
S3method(et_plot_coefficients,et_model)
S3method(et_plot_coefficients,et_model_list)
S3method(et_predict,et_model)
S3method(et_predict,et_model_list)
S3method(extract_priors,cv.glmnet)
S3method(extract_priors,glm)
S3method(extract_priors,glmnet)
S3method(extract_priors,lm)
S3method(extract_priors,ranger)
S3method(print,et_model)
S3method(print,et_model_list)
S3method(print,et_prediction)
S3method(print,et_prediction_list)
S3method(print,et_prior_spec)
S3method(print,et_sensitivity)
S3method(print,et_shelf_life)
S3method(shelf_life,default)
S3method(shelf_life,et_prediction)
S3method(shelf_life,et_prediction_list)
S3method(summary,et_model)
S3method(summary,et_model_list)
S3method(summary,et_shelf_life)
export(decompose_uncertainty)
export(et_calibrate)
export(et_diagnose)
export(et_fit)
export(et_plot_calibration)
export(et_plot_coefficients)
export(et_plot_decomposition)
export(et_plot_forecast)
export(et_plot_prior_posterior)
export(et_plot_sensitivity)
export(et_plot_shelf_life)
export(et_predict)
export(et_sensitivity_profile)
export(et_theme)
export(extract_priors)
export(shelf_life)
export(standardize)
export(unstandardize)
importFrom(rlang,.data)
importFrom(stats,coef)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(utils,head)
