% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot.R
\name{et_plot_coefficients}
\alias{et_plot_coefficients}
\title{Forest plot of regression coefficients}
\usage{
et_plot_coefficients(model)
}
\arguments{
\item{model}{An \code{et_model} or \code{et_model_list}.}
}
\value{
A \code{ggplot2} object.
}
\description{
Compares Bayesian posterior estimates (95\% CI) with the regularized
coefficient values used as prior means (shown as crosses).
}
