% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{unstandardize}
\alias{unstandardize}
\title{Reverse standardization}
\usage{
unstandardize(z, mu, s)
}
\arguments{
\item{z}{Standardized values.}

\item{mu}{Original mean.}

\item{s}{Original standard deviation.}
}
\value{
Values on the original scale.
}
\description{
Reverse standardization
}
