% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{standardize}
\alias{standardize}
\title{Standardize a numeric vector (mean-centre, unit-variance)}
\usage{
standardize(x)
}
\arguments{
\item{x}{Numeric vector.}
}
\value{
Standardized numeric vector. Returns zeros if variance is zero.
}
\description{
Standardize a numeric vector (mean-centre, unit-variance)
}
