% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{et_theme}
\alias{et_theme}
\title{Minimal ggplot2 theme for ErrorTracer plots}
\usage{
et_theme(base_size = 12)
}
\arguments{
\item{base_size}{Base font size (default 12).}
}
\value{
A \code{ggplot2} theme object.
}
\description{
Minimal ggplot2 theme for ErrorTracer plots
}
